#ifndef _REGISTER_H
#define _REGISTER_H

#include "defBF535.h"

#define PVUL volatile unsigned long *
#define PVUS volatile unsigned short *
#define PVUB volatile unsigned char *

// NOTE: CHIPID is defined to the wrong value in <def21535.h> use chipId 
//       instead

#define chipId                   0xFFC048C0      // Chip ID Register

/************************************************************************************
						System MMR Register
*************************************************************************************/

/*==================================================================================
	L2 MISR MMRs (0xFFC0 0000-0xFFC0 03FF)
====================================================================================*/
#define MISR_CTL_REG	(*(PVUL)(MISR_CTL))	   // Control Register
#define MISR_RMISR0_REG (*(PVUL)(MISR_RMISR0)) // coreL2[31:0] read bus
#define MISR_RMISR1_REG (*(PVUL)(MISR_RMISR1)) // coreL2[63:32] read bus
#define MISR_RMISR2_REG (*(PVUL)(MISR_RMISR2)) // sysL2[31:0] read bus
#define MISR_WMISR0_REG (*(PVUL)(MISR_WMISR0)) // coreL2[31:0] write bus
#define MISR_WMISR1_REG (*(PVUL)(MISR_WMISR1)) // coreL2[63:32] write bus
#define MISR_WMISR2_REG (*(PVUL)(MISR_WMISR2)) // sysL2[31:0] write bus

/*==================================================================================
// Clock and System Control (0xFFC0 0400-0xFFC0 07FF)
====================================================================================*/
#define PLLCTL_REG  (*(PVUL)(PLLCTL))  // PLL Control register (32-bit)
#define PLLSTAT_REG (*(PVUS)(PLLSTAT)) // PLL Status register
#define LOCKCNT_REG (*(PVUS)(LOCKCNT)) // PLL Lock Counter register
#define IOCKR_REG   (*(PVUS)(IOCKR))   // Peripheral Clock Enable register (32-bit)
#define SWRST_REG   (*(PVUL)(SWRST))   // Software Reset Register
#define SYSCR_REG   (*(PVUS)(SYSCR))   // System Configuration register (RCSR)

/*==================================================================================
// JTAG/Debug Communication Channel (0xFFC0 0800-0xFFC0 0BFF)
====================================================================================*/
#define CHIPID_REG  (*(PVUL)(CHIPID))  // Device ID Register
#define chipId_REG  (*(PVUL)(chipId))  // Device ID Register
 
/*==================================================================================
// System Interrupt Controller (0xFFC0 0C00-0xFFC0 0FFF)
====================================================================================*/
#define SIC_RVECT_REG (*(PVUL)(SIC_RVECT))  // Reset Vector Register
#define SIC_IAR0_REG  (*(PVUL)(SIC_IAR0))   // Interrupt Assignment Register 0
#define SIC_IAR1_REG  (*(PVUL)(SIC_IAR1))   // Interrupt Assignment Register 1
#define SIC_IAR2_REG  (*(PVUL)(SIC_IAR2))   // Interrupt Assignment Register 2
#define SIC_IMASK_REG (*(PVUL)(SIC_IMASK))  // Interrupt Mask Register
#define SIC_ISR_REG   (*(PVUL)(SIC_ISR))    // Interrupt Status Register
#define SIC_IWR_REG   (*(PVUL)(SIC_IWR))    // Interrupt Wakeup Register

/*==================================================================================
// Watchdog Timer (0xFFC0 1000-0xFFC0 13FF)
====================================================================================*/
#define WDOGCTL_REG  (*(PVUL)(WDOGCTL))   // Watchdog Control Register
#define WDOGCNT_REG  (*(PVUL)(WDOGCNT))   // Watchdog Count Register
#define WDOGSTAT_REG (*(PVUL)(WDOGSTAT))  // Watchdog Status Register

/*==================================================================================
// Real Time Clock (0xFFC0 1400-0xFFC0 17FF)
====================================================================================*/
#define RTCSTAT_REG  (*(PVUL)(RTCSTAT))   // RTC Status Register
#define RTCICTL_REG  (*(PVUL)(RTCICTL))   // RTC Interrupt Control Register
#define RTCISTAT_REG (*(PVUL)(RTCISTAT))  // RTC Interrupt Status Register
#define RTCSWCNT_REG (*(PVUL)(RTCSWCNT))  // RTC Stopwatch Count Register
#define RTCALARM_REG (*(PVUL)(RTCALARM))  // RTC Alarm Time Register
#define RTCFAST_REG  (*(PVUL)(RTCFAST))   // RTC Prescaler Control Register

/*==================================================================================
// UART 0 Controller (0xFFC0 1800-0xFFC0 1BFF)
====================================================================================*/
#define UART0_THR_REG               (*(PVUB)(UART0_THR)) // Transmit Holding register
#define UART0_RBR_REG               (*(PVUB)(UART0_RBR)) // Receive Buffer register
#define UART0_DLL_REG               (*(PVUB)(UART0_DLL)) // Divisor Latch (Low-Byte)
#define UART0_IER_REG               (*(PVUB)(UART0_IER)) // Interrupt Enable Register
#define UART0_DLH_REG               (*(PVUB)(UART0_DLH)) // Divisor Latch (High-Byte)
#define UART0_IIR_REG               (*(PVUB)(UART0_IIR)) // Interrupt Identification Register
#define UART0_LCR_REG               (*(PVUB)(UART0_LCR)) // Line Control Register
#define UART0_MCR_REG               (*(PVUB)(UART0_MCR)) // Module Control Register
#define UART0_LSR_REG               (*(PVUB)(UART0_LSR)) // Line Status Register
#define UART0_MSR_REG               (*(PVUB)(UART0_MSR)) // MSR Modem Status Register
#define UART0_SCR_REG               (*(PVUB)(UART0_SCR)) // SCR Scratch Register
#define UART0_IRCR_REG              (*(PVUB)(UART0_IRCR))// IRCR IrDA Control Register
#define UART0_CURR_PTR_RX_REG       (*(PVUS)(UART0_CURR_PTR_RX))	  // UART -DMA RCV Current Pointer register
#define UART0_CONFIG_RX_REG         (*(PVUS)(UART0_CONFIG_RX))		  // UART -RCV DMA Configuration register
#define UART0_START_ADDR_HI_RX_REG  (*(PVUS)(UART0_START_ADDR_HI_RX)) // UART -RCV DMA Start Page register
#define UART0_START_ADDR_LO_RX_REG  (*(PVUS)(UART0_START_ADDR_LO_RX)) // UART -RCV DMA Start Address register
#define UART0_COUNT_RX_REG          (*(PVUS)(UART0_COUNT_RX))		  // UART -RCV DMA Count register
#define UART0_NEXT_DESCR_RX_REG     (*(PVUS)(UART0_NEXT_DESCR_RX))    // UART -RCV DMA Next Descriptor Pointer register
#define UART0_DESCR_RDY_RX_REG      (*(PVUS)(UART0_DESCR_RDY_RX))     // UART -RCV DMA Descriptor Ready
#define UART0_IRQSTAT_RX_REG        (*(PVUS)(UART0_IRQSTAT_RX))       // UART -RCV DMA Interrupt Register
#define UART0_CURR_PTR_TX_REG       (*(PVUS)(UART0_CURR_PTR_TX))      // UART -XMT DMA Current Pointer register
#define UART0_CONFIG_TX_REG         (*(PVUS)(UART0_CONFIG_TX))        // UART -XMT DMA Configuration register
#define UART0_START_ADDR_HI_TX_REG  (*(PVUS)(UART0_START_ADDR_HI_TX)) // UART -XMT DMA Start Page register
#define UART0_START_ADDR_LO_TX_REG  (*(PVUS)(UART0_START_ADDR_LO_TX)) // UART -XMT DMA Start Address register
#define UART0_COUNT_TX_REG          (*(PVUS)(UART0_COUNT_TX))         // UART -XMT DMA Count register
#define UART0_NEXT_DESCR_TX_REG     (*(PVUS)(UART0_NEXT_DESCR_TX))    // UART -XMT DMA Next Descriptor Pointer register
#define UART0_DESCR_RDY_TX_REG      (*(PVUS)(UART0_DESCR_RDY_TX))     // UART -XMT DMA Descriptor Ready
#define UART0_IRQSTAT_TX_REG		(*(PVUS)(UART0_IRQSTAT_TX))       // UART -XMT DMA Interrupt register

/*==================================================================================
// UART 1 Controller (0xFFC0 1C00-0xFFC0 1FFF)
====================================================================================*/
#define UART1_THR_REG               (*(PVUB)(UART1_THR))  // Transmit Holding register
#define UART1_RBR_REG               (*(PVUB)(UART1_RBR))  // Receive Buffer register
#define UART1_DLL_REG               (*(PVUB)(UART1_DLL))  // Divisor Latch (Low-Byte)
#define UART1_IER_REG               (*(PVUB)(UART1_IER))  // Interrupt Enable Register
#define UART1_DLH_REG               (*(PVUB)(UART1_DLH))  // Divisor Latch (High-Byte)
#define UART1_IIR_REG               (*(PVUB)(UART1_IIR))  // Interrupt Identification Register
#define UART1_LCR_REG               (*(PVUB)(UART1_LCR))  // Line Control Register
#define UART1_MCR_REG               (*(PVUB)(UART1_MCR))  // Module Control Register
#define UART1_LSR_REG               (*(PVUB)(UART1_LSR))  // Line Status Register
#define UART1_MSR_REG               (*(PVUB)(UART1_MSR))  // MSR Modem Status Register
#define UART1_SCR_REG               (*(PVUB)(UART1_SCR))  // SCR Scratch Register
#define UART1_CURR_PTR_RX_REG       (*(PVUS)(UART1_CURR_PTR_RX))      // UART -DMA RCV Current Pointer register
#define UART1_CONFIG_RX_REG         (*(PVUS)(UART1_CONFIG_RX))        // UART -RCV DMA Configuration register
#define UART1_START_ADDR_HI_RX_REG  (*(PVUS)(UART1_START_ADDR_HI_RX)) // UART -RCV DMA Start Page register
#define UART1_START_ADDR_LO_RX_REG  (*(PVUS)(UART1_START_ADDR_LO_RX)) // UART -RCV DMA Start Address register
#define UART1_COUNT_RX_REG          (*(PVUS)(UART1_COUNT_RX))         // UART -RCV DMA Count register
#define UART1_NEXT_DESCR_RX_REG     (*(PVUS)(UART1_NEXT_DESCR_RX))    // UART -RCV DMA Next Descriptor Pointer register
#define UART1_DESCR_RDY_RX_REG      (*(PVUS)(UART1_DESCR_RDY_RX))     // UART -RCV DMA Descriptor Ready
#define UART1_IRQSTAT_RX_REG        (*(PVUS)(UART1_IRQSTAT_RX))       // UART -RCV DMA Interrupt Register
#define UART1_CURR_PTR_TX_REG       (*(PVUS)(UART1_CURR_PTR_TX))      // UART -XMT DMA Current Pointer register
#define UART1_CONFIG_TX_REG         (*(PVUS)(UART1_CONFIG_TX))        // UART -XMT DMA Configuration register
#define UART1_START_ADDR_HI_TX_REG  (*(PVUS)(UART1_START_ADDR_HI_TX)) // UART -XMT DMA Start Page register
#define UART1_START_ADDR_LO_TX_REG  (*(PVUS)(UART1_START_ADDR_LO_TX)) // UART -XMT DMA Start Address register
#define UART1_COUNT_TX_REG          (*(PVUS)(UART1_COUNT_TX))         // UART -XMT DMA Count register
#define UART1_NEXT_DESCR_TX_REG     (*(PVUS)(UART1_NEXT_DESCR_TX))   // UART -XMT DMA Next Descriptor Pointer register
#define UART1_DESCR_RDY_TX_REG      (*(PVUS)(UART1_DESCR_RDY_TX))    // UART -XMT DMA Descriptor Ready
#define UART1_IRQSTAT_TX_REG        (*(PVUS)(UART1_IRQSTAT_TX))      // UART -XMT DMA Interrupt register

/*==================================================================================
// TIMER 0, 1, 2 Registers (0xFFC0 2000-0xFFC0 23FF)
====================================================================================*/
#define TIMER0_STATUS_REG     (*(PVUS)(TIMER0_STATUS))     // Timer 0 Global Status and Sticky Register
#define TIMER0_CONFIG_REG     (*(PVUS)(TIMER0_CONFIG))     // Timer 0 configuration Register
#define TIMER0_COUNTER_LO_REG (*(PVUS)(TIMER0_COUNTER_LO)) // Timer 0 Counter Register (low word)
#define TIMER0_COUNTER_HI_REG (*(PVUS)(TIMER0_COUNTER_HI)) // Timer 0 Counter Register (high word)
#define TIMER0_PERIOD_LO_REG  (*(PVUS)(TIMER0_PERIOD_LO))  // Timer 0 Period Register (low word)
#define TIMER0_PERIOD_HI_REG  (*(PVUS)(TIMER0_PERIOD_HI))  // Timer 0 Period Register (high word)
#define TIMER0_WIDTH_LO_REG   (*(PVUS)(TIMER0_WIDTH_LO))   // Timer 0 Width Register (low word)
#define TIMER0_WIDTH_HI_REG   (*(PVUS)(TIMER0_WIDTH_HI))   // Timer 0 Width Register (high word)
#define TIMER1_STATUS_REG     (*(PVUS)(TIMER1_STATUS))     // Timer 1 Global Status and Sticky Register
#define TIMER1_CONFIG_REG     (*(PVUS)(TIMER1_CONFIG))     // Timer 1 configuration register
#define TIMER1_COUNTER_LO_REG (*(PVUS)(TIMER1_COUNTER_LO)) // Timer 1 Counter Register (low word)
#define TIMER1_COUNTER_HI_REG (*(PVUS)(TIMER1_COUNTER_HI)) // Timer 1 Counter Register (high word)
#define TIMER1_PERIOD_LO_REG  (*(PVUS)(TIMER1_PERIOD_LO))  // Timer 1 Period Register (low word)
#define TIMER1_PERIOD_HI_REG  (*(PVUS)(TIMER1_PERIOD_HI))  // Timer 1 Period Register (high word)
#define TIMER1_WIDTH_LO_REG   (*(PVUS)(TIMER1_WIDTH_LO))   // Timer 1 Width Register (low word)
#define TIMER1_WIDTH_HI_REG   (*(PVUS)(TIMER1_WIDTH_HI))   // Timer 1 Width Register (high word)
#define TIMER2_STATUS_REG     (*(PVUS)(TIMER2_STATUS))     // Timer 2 Global Status and Sticky Register
#define TIMER2_CONFIG_REG     (*(PVUS)(TIMER2_CONFIG))     // Timer 2 configuration register
#define TIMER2_COUNTER_LO_REG (*(PVUS)(TIMER2_COUNTER_LO)) // Timer 2 Counter Register (low word)
#define TIMER2_COUNTER_HI_REG (*(PVUS)(TIMER2_COUNTER_HI)) // Timer 2 Counter Register (high word)
#define TIMER2_PERIOD_LO_REG  (*(PVUS)(TIMER2_PERIOD_LO))  // Timer 2 Period Register (low word)
#define TIMER2_PERIOD_HI_REG  (*(PVUS)(TIMER2_PERIOD_HI))  // Timer 2 Period Register (high word)
#define TIMER2_WIDTH_LO_REG   (*(PVUS)(TIMER2_WIDTH_LO))   // Timer 2 Width Register (low word)
#define TIMER2_WIDTH_HI_REG   (*(PVUS)(TIMER2_WIDTH_HI))   // Timer 2 Width Register (high word)

/*==================================================================================
// General Purpose IO (0xFFC0 2400-0xFFC0 27FF)
====================================================================================*/
#define FIO_DIR_REG     (*(PVUS)(FIO_DIR))     // Peripheral Flag Direction Register
#define FIO_FLAG_C_REG  (*(PVUS)(FIO_FLAG_C))  // Peripheral Interrupt Flag Register (clear)
#define FIO_FLAG_S_REG  (*(PVUS)(FIO_FLAG_S))  // Peripheral Interrupt Flag Register (set)
#define FIO_MASKA_C_REG (*(PVUS)(FIO_MASKA_C)) // Flag Mask Interrupt A Register (clear)
#define FIO_MASKA_S_REG (*(PVUS)(FIO_MASKA_S)) // Flag Mask Interrupt A Register (set)
#define FIO_MASKB_C_REG (*(PVUS)(FIO_MASKB_C)) // Flag Mask Interrupt B Register (clear)
#define FIO_MASKB_S_REG (*(PVUS)(FIO_MASKB_S)) // Flag Mask Interrupt B Register (set)
#define FIO_POLAR_REG   (*(PVUS)(FIO_POLAR))   // Flag Source Polarity Register
#define FIO_EDGE_REG    (*(PVUS)(FIO_EDGE))    // Flag Source Sensitivity Register
#define FIO_BOTH_REG    (*(PVUS)(FIO_BOTH))    // Flag Set on BOTH Edges Register

/*==================================================================================
// SPORT0 Controller (0xFFC0 2800-0xFFC0 2BFF)
====================================================================================*/
#define SPORT0_TX_CONFIG_REG        (*(PVUS)(SPORT0_TX_CONFIG)) // SPORT0 Transmit Configuration Register
#define SPORT0_RX_CONFIG_REG        (*(PVUS)(SPORT0_RX_CONFIG)) // SPORT0 Receive Configuration Register
#define SPORT0_TX_REG               (*(PVUS)(SPORT0_TX))        // SPORT0 TX transmit Register
#define SPORT0_RX_REG               (*(PVUS)(SPORT0_RX))        // SPORT0 RX Receive register
#define SPORT0_TSCLKDIV_REG         (*(PVUS)(SPORT0_TSCLKDIV))  // SPORT0 Transmit Serial Clock Divider
#define SPORT0_RSCLKDIV_REG         (*(PVUS)(SPORT0_RSCLKDIV))  // SPORT0 Receive Serial Clock Divider
#define SPORT0_TFSDIV_REG           (*(PVUS)(SPORT0_TFSDIV))    // SPORT0 Transmit Frame Sync Divider
#define SPORT0_RFSDIV_REG           (*(PVUS)(SPORT0_RFSDIV))    // SPORT0 Receive Frame Sync Divider
#define SPORT0_STAT_REG             (*(PVUS)(SPORT0_STAT))      /// SPORT0 Status Register
#define SPORT0_MTCS0_REG            (*(PVUS)(SPORT0_MTCS0)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS1_REG            (*(PVUS)(SPORT0_MTCS1)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS2_REG            (*(PVUS)(SPORT0_MTCS2)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS3_REG            (*(PVUS)(SPORT0_MTCS3)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS4_REG            (*(PVUS)(SPORT0_MTCS4)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS5_REG            (*(PVUS)(SPORT0_MTCS5)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS6_REG            (*(PVUS)(SPORT0_MTCS6)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MTCS7_REG            (*(PVUS)(SPORT0_MTCS7)) // SPORT0 Multi-Channel Transmit Select Register
#define SPORT0_MRCS0_REG            (*(PVUS)(SPORT0_MRCS0)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS1_REG            (*(PVUS)(SPORT0_MRCS1)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS2_REG            (*(PVUS)(SPORT0_MRCS2)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS3_REG            (*(PVUS)(SPORT0_MRCS3)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS4_REG            (*(PVUS)(SPORT0_MRCS4)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS5_REG            (*(PVUS)(SPORT0_MRCS5)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS6_REG            (*(PVUS)(SPORT0_MRCS6)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MRCS7_REG            (*(PVUS)(SPORT0_MRCS7)) // SPORT0 Multi-Channel Receive Select Register
#define SPORT0_MCMC1_REG            (*(PVUS)(SPORT0_MCMC1)) // SPORT0 Multi-Channel Configuration Register 1
#define SPORT0_MCMC2_REG            (*(PVUS)(SPORT0_MCMC2)) // SPORT0 Multi-Channel Configuration Register 2
#define SPORT0_CURR_PTR_RX_REG      (*(PVUS)(SPORT0_CURR_PTR_RX))     // SPORT0 -RCV DMA Current Pointer
#define SPORT0_CONFIG_DMA_RX_REG    (*(PVUS)(SPORT0_CONFIG_DMA_RX))   // SPORT0 -RCV DMA Configuration
#define SPORT0_START_ADDR_HI_RX_REG (*(PVUS)(SPORT0_START_ADDR_HI_RX))// SPORT0 -RCV DMA Start Page
#define SPORT0_START_ADDR_LO_RX_REG (*(PVUS)(SPORT0_START_ADDR_LO_RX))// SPORT0 -RCV DMA Start Address
#define SPORT0_COUNT_RX_REG         (*(PVUS)(SPORT0_COUNT_RX))        // SPORT0 -RCV DMA Count
#define SPORT0_NEXT_DESCR_RX_REG    (*(PVUS)(SPORT0_NEXT_DESCR_RX))   // SPORT0 -RCV DMA Next Descriptor Pointer
#define SPORT0_DESCR_RDY_RX_REG     (*(PVUS)(SPORT0_DESCR_RDY_RX))    // SPORT0 -RCV DMA Descriptor Ready
#define SPORT0_IRQSTAT_RX_REG       (*(PVUS)(SPORT0_IRQSTAT_RX))      // SPORT0 -RCV DMA Interrupt Register
#define SPORT0_CURR_PTR_TX_REG      (*(PVUS)(SPORT0_CURR_PTR_TX))     // SPORT0 -XMT DMA Current Pointer
#define SPORT0_CONFIG_DMA_TX_REG    (*(PVUS)(SPORT0_CONFIG_DMA_TX))   // SPORT0 -XMT DMA Configuration
#define SPORT0_START_ADDR_HI_TX_REG (*(PVUS)(SPORT0_START_ADDR_HI_TX))// SPORT0 -XMT DMA Start Page
#define SPORT0_START_ADDR_LO_TX_REG (*(PVUS)(SPORT0_START_ADDR_LO_TX))// SPORT0 -XMT DMA Start Address
#define SPORT0_COUNT_TX_REG         (*(PVUS)(SPORT0_COUNT_TX))        // SPORT0 -XMT DMA Count
#define SPORT0_NEXT_DESCR_TX_REG    (*(PVUS)(SPORT0_NEXT_DESCR_TX))   // SPORT0 -XMT DMA Next Descriptor Pointer
#define SPORT0_DESCR_RDY_TX_REG     (*(PVUS)(SPORT0_DESCR_RDY_TX))    // SPORT0 -XMT DMA Descriptor Ready
#define SPORT0_IRQSTAT_TX_REG       (*(PVUS)(SPORT0_IRQSTAT_TX))      // SPORT0 -XMT DMA Interrupt Register

/*==================================================================================
// SPORT1 Controller (0xFFC0 2C00-0xFFC0 2FFF)
====================================================================================*/
#define SPORT1_TX_CONFIG_REG        (*(PVUS)(SPORT1_TX_CONFIG)) // SPORT1 Transmit Configuration Register
#define SPORT1_RX_CONFIG_REG        (*(PVUS)(SPORT1_RX_CONFIG)) // SPORT1 Receive Configuration Register
#define SPORT1_TX_REG               (*(PVUS)(SPORT1_TX))        // SPORT1 TX transmit Register
#define SPORT1_RX_REG               (*(PVUS)(SPORT1_RX))        // SPORT1 RX Receive register
#define SPORT1_TSCLKDIV_REG         (*(PVUS)(SPORT1_TSCLKDIV))  // SPORT1 Transmit Serial Clock Divider
#define SPORT1_RSCLKDIV_REG         (*(PVUS)(SPORT1_RSCLKDIV))  // SPORT1 Receive Serial Clock Divider
#define SPORT1_TFSDIV_REG           (*(PVUS)(SPORT1_TFSDIV))    // SPORT1 Transmit Frame Sync Divider
#define SPORT1_RFSDIV_REG           (*(PVUS)(SPORT1_RFSDIV))    // SPORT1 Receive Frame Sync Divider
#define SPORT1_STAT_REG             (*(PVUS)(SPORT1_STAT))  // SPORT1 Status Register
#define SPORT1_MTCS0_REG            (*(PVUS)(SPORT1_MTCS0)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS1_REG            (*(PVUS)(SPORT1_MTCS1)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS2_REG            (*(PVUS)(SPORT1_MTCS2)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS3_REG            (*(PVUS)(SPORT1_MTCS3)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS4_REG            (*(PVUS)(SPORT1_MTCS4)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS5_REG            (*(PVUS)(SPORT1_MTCS5)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS6_REG            (*(PVUS)(SPORT1_MTCS6)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MTCS7_REG            (*(PVUS)(SPORT1_MTCS7)) // SPORT1 Multi-Channel Transmit Select Register
#define SPORT1_MRCS0_REG            (*(PVUS)(SPORT1_MRCS0)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS1_REG            (*(PVUS)(SPORT1_MRCS1)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS2_REG            (*(PVUS)(SPORT1_MRCS2)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS3_REG            (*(PVUS)(SPORT1_MRCS3)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS4_REG            (*(PVUS)(SPORT1_MRCS4)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS5_REG            (*(PVUS)(SPORT1_MRCS5)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS6_REG            (*(PVUS)(SPORT1_MRCS6)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MRCS7_REG            (*(PVUS)(SPORT1_MRCS7)) // SPORT1 Multi-Channel Receive Select Register
#define SPORT1_MCMC1_REG            (*(PVUS)(SPORT1_MCMC1)) // SPORT1 Multi-Channel Configuration Register 1
#define SPORT1_MCMC2_REG            (*(PVUS)(SPORT1_MCMC2)) // SPORT1 Multi-Channel Configuration Register 2
#define SPORT1_CURR_PTR_RX_REG      (*(PVUS)(SPORT1_CURR_PTR_RX))     // SPORT1 -RCV DMA Current Pointer
#define SPORT1_CONFIG_DMA_RX_REG    (*(PVUS)(SPORT1_CONFIG_DMA_RX))   // SPORT1 -RCV DMA Configuration
#define SPORT1_START_ADDR_HI_RX_REG (*(PVUS)(SPORT1_START_ADDR_HI_RX))// SPORT1 -RCV DMA Start Page
#define SPORT1_START_ADDR_LO_RX_REG (*(PVUS)(SPORT1_START_ADDR_LO_RX))// SPORT1 -RCV DMA Start Address
#define SPORT1_COUNT_RX_REG         (*(PVUS)(SPORT1_COUNT_RX))        // SPORT1 -RCV DMA Count
#define SPORT1_NEXT_DESCR_RX_REG    (*(PVUS)(SPORT1_NEXT_DESCR_RX))   // SPORT1 -RCV DMA Next Descriptor Pointer
#define SPORT1_DESCR_RDY_RX_REG     (*(PVUS)(SPORT1_DESCR_RDY_RX))    // SPORT1 -RCV DMA Descriptor Ready
#define SPORT1_IRQSTAT_RX_REG       (*(PVUS)(SPORT1_IRQSTAT_RX))      // SPORT1 -RCV DMA Interrupt Register
#define SPORT1_CURR_PTR_TX_REG      (*(PVUS)(SPORT1_CURR_PTR_TX))     // SPORT1 -XMT DMA Current Pointer
#define SPORT1_CONFIG_DMA_TX_REG    (*(PVUS)(SPORT1_CONFIG_DMA_TX))   // SPORT1 -XMT DMA Configuration
#define SPORT1_START_ADDR_HI_TX_REG (*(PVUS)(SPORT1_START_ADDR_HI_TX))// SPORT1 -XMT DMA Start Page
#define SPORT1_START_ADDR_LO_TX_REG (*(PVUS)(SPORT1_START_ADDR_LO_TX))// SPORT1 -XMT DMA Start Address
#define SPORT1_COUNT_TX_REG         (*(PVUS)(SPORT1_COUNT_TX))        // SPORT1 -XMT DMA Count
#define SPORT1_NEXT_DESCR_TX_REG    (*(PVUS)(SPORT1_NEXT_DESCR_TX))   // SPORT1 -XMT DMA Next Descriptor Pointer
#define SPORT1_DESCR_RDY_TX_REG     (*(PVUS)(SPORT1_DESCR_RDY_TX))    // SPORT1 -XMT DMA Descriptor Ready
#define SPORT1_IRQSTAT_TX_REG       (*(PVUS)(SPORT1_IRQSTAT_TX))      // SPORT1 -XMT DMA Interrupt Register

/*==================================================================================
// SPI 0 Controller (0xFFC0 3000-0xFFC0 33FF)
====================================================================================*/
#define SPI0_CTL_REG           (*(PVUS)(SPI0_CTL))      // SPI0 Control Register
#define SPI0_FLG_REG           (*(PVUS)(SPI0_FLG))      // SPI0 Flag register
#define SPI0_ST_REG            (*(PVUS)(SPI0_ST))       // SPI0 Status register
#define SPI0_TDBR_REG          (*(PVUS)(SPI0_TDBR))     // SPI0 Transmit Data Buffer Register
#define SPI0_RDBR_REG          (*(PVUS)(SPI0_RDBR))     // SPI0 Receive Data Buffer Register
#define SPI0_BAUD_REG          (*(PVUS)(SPI0_BAUD))     // SPI0 Baud rate Register
#define SPI0_SHADOW_REG        (*(PVUS)(SPI0_SHADOW))        
#define SPI0_CURR_PTR_REG      (*(PVUS)(SPI0_CURR_PTR)) // SPI0 -DMA Current Pointer register
#define SPI0_CONFIG_REG        (*(PVUS)(SPI0_CONFIG))   // SPI0 -DMA Configuration register
#define SPI0_START_ADDR_HI_REG (*(PVUS)(SPI0_START_ADDR_HI))  // SPI0 -DMA Start Page register
#define SPI0_START_ADDR_LO_REG (*(PVUS)(SPI0_START_ADDR_LO))  // SPI0 -DMA Start Address register
#define SPI0_COUNT_REG         (*(PVUS)(SPI0_COUNT))     // SPI0 -DMA Count register
#define SPI0_NEXT_DESCR_REG    (*(PVUS)(SPI0_NEXT_DESCR))// SPI0 -DMA Next Descriptor Pointer
#define SPI0_DESCR_RDY_REG     (*(PVUS)(SPI0_DESCR_RDY)) // SPI0 -DMA Descriptor Ready
#define SPI0_DMA_INT_REG       (*(PVUS)(SPI0_DMA_INT))   // SPI0 -DMA Interrupt register

/*==================================================================================
// SPI 1 Controller (0xFFC0 3400-0xFFC0 37FF)
====================================================================================*/
#define SPI1_CTL_REG           (*(PVUS)(SPI1_CTL))      // SPI1 Control Register
#define SPI1_FLG_REG           (*(PVUS)(SPI1_FLG))      // SPI1 Flag register
#define SPI1_ST_REG            (*(PVUS)(SPI1_ST))       // SPI1 Status register
#define SPI1_TDBR_REG          (*(PVUS)(SPI1_TDBR))     // SPI1 Transmit Data Buffer Register
#define SPI1_RDBR_REG          (*(PVUS)(SPI1_RDBR))     // SPI1 Receive Data Buffer Register
#define SPI1_BAUD_REG          (*(PVUS)(SPI1_BAUD))     // SPI1 Baud rate Register
#define SPI1_SHADOW_REG        (*(PVUS)(SPI1_SHADOW))   
#define SPI1_CURR_PTR_REG      (*(PVUS)(SPI1_CURR_PTR)) // SPI1 -DMA Current Pointer register
#define SPI1_CONFIG_REG        (*(PVUS)(SPI1_CONFIG))   // SPI1 -DMA Configuration register
#define SPI1_START_ADDR_HI_REG (*(PVUS)(SPI1_START_ADDR_HI)) // SPI1 -DMA Start Page register
#define SPI1_START_ADDR_LO_REG (*(PVUS)(SPI1_START_ADDR_LO)) // SPI1 -DMA Start Address register
#define SPI1_COUNT_REG         (*(PVUS)(SPI1_COUNT))     // SPI1 -DMA Count register
#define SPI1_NEXT_DESCR_REG    (*(PVUS)(SPI1_NEXT_DESCR))// SPI1 -DMA Next Descriptor Pointer
#define SPI1_DESCR_RDY_REG     (*(PVUS)(SPI1_DESCR_RDY)) // SPI1 -DMA Descriptor Ready
#define SPI1_DMA_INT_REG       (*(PVUS)(SPI1_DMA_INT))   // SPI1 -DMA Interrupt register

/*==================================================================================
// Memory DMA Controller (0xFFC0 3800-0xFFC0 3BFF)
====================================================================================*/
#define MDW_DCP_REG  (*(PVUS)(MDW_DCP))  // Current Pointer - Write Channel
#define MDW_DCFG_REG (*(PVUS)(MDW_DCFG)) // DMA Configuration - Write Channel
#define MDW_DSAH_REG (*(PVUS)(MDW_DSAH)) // Start Address Hi - Write Channel
#define MDW_DSAL_REG (*(PVUS)(MDW_DSAL)) // Start Address Lo - Write Channel
#define MDW_DCT_REG  (*(PVUS)(MDW_DCT))  // DMA Count - Write Channel
#define MDW_DND_REG  (*(PVUS)(MDW_DND))  // Next Descriptor Pointer - Write Channel
#define MDW_DDR_REG  (*(PVUS)(MDW_DDR))  // Descriptor Ready - Write Channel
#define MDW_DI_REG   (*(PVUS)(MDW_DI))   // DMA Interrupt - Write Channel
#define MDR_DCP_REG  (*(PVUS)(MDR_DCP))  // Current Pointer - Read Channel
#define MDR_DCFG_REG (*(PVUS)(MDR_DCFG)) // DMA Configuration - Read Channel
#define MDR_DSAH_REG (*(PVUS)(MDR_DSAH)) // Start Address Hi - Read Channel
#define MDR_DSAL_REG (*(PVUS)(MDR_DSAL)) // Start Address Lo - Read Channel
#define MDR_DCT_REG  (*(PVUS)(MDR_DCT))  // DMA Count - Read Channel
#define MDR_DND_REG  (*(PVUS)(MDR_DND))  // Next Descriptor Pointer - Read Channel
#define MDR_DDR_REG  (*(PVUS)(MDR_DDR))  // Descriptor Ready - Read Channel
#define MDR_DI_REG   (*(PVUS)(MDR_DI))   // DMA Interrupt - Read Channel

/*==================================================================================
// Aysnchronous Memory Controller - External Bus Interface Unit (0xFFC0 3C00-0xFFC0 3FFF)
====================================================================================*/
#define EBIU_AMGCTL_REG  (*(PVUS)(EBIU_AMGCTL))  // Asynchronous Memory Global Control Register
#define EBIU_AMBCTL0_REG (*(PVUL)(EBIU_AMBCTL0)) // Asynchronous Memory Bank Control Register 0
#define EBIU_AMBCTL1_REG (*(PVUL)(EBIU_AMBCTL1)) // Asynchronous Memory Bank Control Register 1

/*==================================================================================
// PCI Bridge PAB Registers (0xFFC0 4000-0xFFC0 43FF)
====================================================================================*/
#define PCI_CTL_REG   (*(PVUL)(PCI_CTL))   // PCI Bridge Control
#define PCI_STAT_REG  (*(PVUL)(PCI_STAT))  // PCI Bridge Status
#define PCI_ICTL_REG  (*(PVUL)(PCI_ICTL))  // PCI Bridge Interrupt Control
#define PCI_MBAP_REG  (*(PVUL)(PCI_MBAP))  // PCI Memory Space Base Address Pointer [31:27]
#define PCI_IBAP_REG  (*(PVUL)(PCI_IBAP))  // PCI IO Space Base Address Pointer
#define PCI_CBAP_REG  (*(PVUL)(PCI_CBAP))  // PCI Config Space Base Address Port
#define PCI_TMBAP_REG (*(PVUL)(PCI_TMBAP)) // PCI to 21535 Memory Base Address Pointer
#define PCI_TIBAP_REG (*(PVUL)(PCI_TIBAP)) // PCI to 21535 IO Base Address Pointer

/*==================================================================================
// PCI Bridge External Access Bus Registers (0xEEFF FF00-0xEEFF FFFF)
====================================================================================*/
#define PCI_DMBARM_REG   (*(PVUL)(PCI_DMBARM))   // PCI Device Memory Bar Mask
#define PCI_DIBARM_REG   (*(PVUL)(PCI_DIBARM))   // PCI Device IO Bar Mask
#define PCI_CFG_DIC_REG  (*(PVUL)(PCI_CFG_DIC))  // PCI Config Device ID
#define PCI_CFG_VIC_REG  (*(PVUL)(PCI_CFG_VIC))  // PCI Config Vendor ID
#define PCI_CFG_STAT_REG (*(PVUL)(PCI_CFG_STAT)) // PCI Config Status (Read-only)
#define PCI_CFG_CMD_REG  (*(PVUL)(PCI_CFG_CMD))  // PCI Config Command
#define PCI_CFG_CC_REG   (*(PVUL)(PCI_CFG_CC))   // PCI Config Class Code
#define PCI_CFG_RID_REG  (*(PVUL)(PCI_CFG_RID))  // PCI Config Revision ID
#define PCI_CFG_BIST_REG (*(PVUL)(PCI_CFG_BIST)) // PCI Config BIST
#define PCI_CFG_HT_REG   (*(PVUL)(PCI_CFG_HT))   // PCI Config Header Type
#define PCI_CFG_MLT_REG  (*(PVUL)(PCI_CFG_MLT))  // PCI Config Memory Latency Timer
#define PCI_CFG_CLS_REG  (*(PVUL)(PCI_CFG_CLS))  // PCI Config Cache Line Size
#define PCI_CFG_MBAR_REG (*(PVUL)(PCI_CFG_MBAR)) // PCI Config Memory Base Address Register
#define PCI_CFG_IBAR_REG (*(PVUL)(PCI_CFG_IBAR)) // PCI Config IO Base Address Register
#define PCI_CFG_SID_REG  (*(PVUL)(PCI_CFG_SID))  // PCI Config Sub-system ID
#define PCI_CFG_SVID_REG (*(PVUL)(PCI_CFG_SVID)) // PCI Config Sub-system Vendor ID
#define PCI_CFG_MAXL_REG (*(PVUL)(PCI_CFG_MAXL)) // PCI Config Maximum Latency Cycles
#define PCI_CFG_MING_REG (*(PVUL)(PCI_CFG_MING)) // PCI Config Minimum Grant Cycles
#define PCI_CFG_IP_REG   (*(PVUL)(PCI_CFG_IP))   // PCI Config Interrupt Pin
#define PCI_CFG_IL_REG   (*(PVUL)(PCI_CFG_IL))   // PCI Config Interrupt Line
#define PCI_HMCTL_REG    (*(PVUL)(PCI_HMCTL))    // PCI Blocking BAR Host Mode Control

/*==================================================================================
// USB Registers (0xFFC0 4400 - 0xFFC0 47FF)
====================================================================================*/
#define USBD_ID_REG      (*(PVUS)(USBD_ID))     // USB Device ID Register
#define USBD_FRM_REG     (*(PVUS)(USBD_FRM))    // Current USB Frame Number
#define USBD_FRMAT_REG   (*(PVUS)(USBD_FRMAT))  // Match value for USB frame number.
#define USBD_EPBUF_REG   (*(PVUS)(USBD_EPBUF))  // Enables Download of Configuration Into UDC Core
#define USBD_STAT_REG    (*(PVUS)(USBD_STAT))   // Returns USBD Module Status
#define USBD_CTRL_REG    (*(PVUS)(USBD_CTRL))   // Allows Configuration and Control of USBD Module.
#define USBD_GINTR_REG   (*(PVUS)(USBD_GINTR))  // Global Interrupt Register
#define USBD_GMASK_REG   (*(PVUS)(USBD_GMASK))  // Global Interrupt Register Mask
#define USBD_DMACFG_REG  (*(PVUS)(USBD_DMACFG)) // DMA Master Channel Configuration Register
#define USBD_DMABL_REG   (*(PVUS)(USBD_DMABL))  // DMA Master Channel Base Address, Low
#define USBD_DMABH_REG   (*(PVUS)(USBD_DMABH))  // DMA Master Channel Base Address, High
#define USBD_DMACT_REG   (*(PVUS)(USBD_DMACT))  // DMA Master Channel Count Register
#define USBD_DMAIRQ_REG  (*(PVUS)(USBD_DMAIRQ)) // DMA Master Channel DMA Count Register
#define USBD_INTR0_REG   (*(PVUS)(USBD_INTR0))  // USB Endpoint 0 Interrupt Register
#define USBD_MASK0_REG   (*(PVUS)(USBD_MASK0))  // USB Endpoint 0 Mask Register
#define USBD_EPCFG0_REG  (*(PVUS)(USBD_EPCFG0)) // USB Endpoint 0 Control Register
#define USBD_EPADR0_REG  (*(PVUS)(USBD_EPADR0)) // USB Endpoint 0 Address Offset Register
#define USBD_EPLEN0_REG  (*(PVUS)(USBD_EPLEN0)) // USB Endpoint 0 Buffer Length Register
#define USBD_INTR1_REG   (*(PVUS)(USBD_INTR1))  // USB Endpoint 1 Interrupt Register
#define USBD_MASK1_REG   (*(PVUS)(USBD_MASK1))  // USB Endpoint 1 Mask Register
#define USBD_EPCFG1_REG  (*(PVUS)(USBD_EPCFG1)) // USB Endpoint 1 Control Register
#define USBD_EPADR1_REG  (*(PVUS)(USBD_EPADR1)) // USB Endpoint 1 Address Offset Register
#define USBD_EPLEN1_REG  (*(PVUS)(USBD_EPLEN1)) // USB Endpoint 1 Buffer Length Register
#define USBD_INTR2_REG   (*(PVUS)(USBD_INTR2))  // USB Endpoint 2 Interrupt Register
#define USBD_MASK2_REG   (*(PVUS)(USBD_MASK2))  // USB Endpoint 2 Mask Register
#define USBD_EPCFG2_REG  (*(PVUS)(USBD_EPCFG2)) // USB Endpoint 2 Control Register
#define USBD_EPADR2_REG  (*(PVUS)(USBD_EPADR2)) // USB Endpoint 2 Address Offset Register
#define USBD_EPLEN2_REG  (*(PVUS)(USBD_EPLEN2)) // USB Endpoint 2 Buffer Length Register
#define USBD_INTR3_REG   (*(PVUS)(USBD_INTR3))  // USB Endpoint 3 Interrupt Register
#define USBD_MASK3_REG   (*(PVUS)(USBD_MASK3))  // USB Endpoint 3 Mask Register
#define USBD_EPCFG3_REG  (*(PVUS)(USBD_EPCFG3)) // USB Endpoint 3 Control Register
#define USBD_EPADR3_REG  (*(PVUS)(USBD_EPADR3)) // USB Endpoint 3 Address Offset Register
#define USBD_EPLEN3_REG  (*(PVUS)(USBD_EPLEN3)) // USB Endpoint 3 Buffer Length Register
#define USBD_INTR4_REG   (*(PVUS)(USBD_INTR4))  // USB Endpoint 4 Interrupt Register
#define USBD_MASK4_REG   (*(PVUS)(USBD_MASK4))  // USB Endpoint 4 Mask Register
#define USBD_EPCFG4_REG  (*(PVUS)(USBD_EPCFG4)) // USB Endpoint 4 Control Register
#define USBD_EPADR4_REG  (*(PVUS)(USBD_EPADR4)) // USB Endpoint 4 Address Offset Register
#define USBD_EPLEN4_REG  (*(PVUS)(USBD_EPLEN4)) // USB Endpoint 4 Buffer Length Register
#define USBD_INTR5_REG   (*(PVUS)(USBD_INTR5))  // USB Endpoint 5 Interrupt Register
#define USBD_MASK5_REG   (*(PVUS)(USBD_MASK5))  // USB Endpoint 5 Mask Register
#define USBD_EPCFG5_REG  (*(PVUS)(USBD_EPCFG5)) // USB Endpoint 5 Control Register
#define USBD_EPADR5_REG  (*(PVUS)(USBD_EPADR5)) // USB Endpoint 5 Address Offset Register
#define USBD_EPLEN5_REG  (*(PVUS)(USBD_EPLEN5)) // USB Endpoint 5 Buffer Length Register
#define USBD_INTR6_REG   (*(PVUS)(USBD_INTR6))  // USB Endpoint 6 Interrupt Register
#define USBD_MASK6_REG   (*(PVUS)(USBD_MASK6))  // USB Endpoint 6 Mask Register
#define USBD_EPCFG6_REG  (*(PVUS)(USBD_EPCFG6)) // USB Endpoint 6 Control Register
#define USBD_EPADR6_REG  (*(PVUS)(USBD_EPADR6)) // USB Endpoint 6 Address Offset Register
#define USBD_EPLEN6_REG  (*(PVUS)(USBD_EPLEN6)) // USB Endpoint 6 Buffer Length Register
#define USBD_INTR7_REG   (*(PVUS)(USBD_INTR7))  // USB Endpoint 7 Interrupt Register
#define USBD_MASK7_REG   (*(PVUS)(USBD_MASK7))  // USB Endpoint 7 Mask Register
#define USBD_EPCFG7_REG  (*(PVUS)(USBD_EPCFG7)) // USB Endpoint 7 Control Register
#define USBD_EPADR7_REG  (*(PVUS)(USBD_EPADR7)) // USB Endpoint 7 Address Offset Register
#define USBD_EPLEN7_REG  (*(PVUS)(USBD_EPLEN7)) // USB Endpoint 7 Buffer Length Register

/*==================================================================================
// System Bus Interface Unit (0xFFC0 4800-0xFFC0 4FFF)
====================================================================================*/
#define L1SBAR_REG    (*(PVUL)(L1SBAR))   // L1 SRAM Base Address Register
#define L1CSR_REG     (*(PVUL)(L1CSR))    // L1 SRAM Control Initialization Register
#define DB_NDBP_REG   (*(PVUL)(DB_NDBP))  // Next Descriptor Base Pointer
#define DB_ACOMP_REG  (*(PVUL)(DB_ACOMP)) // DMA Bus Address Comparator
#define DB_CCOMP_REG  (*(PVUL)(DB_CCOMP)) // DMA Bus Control Comparator

/*==================================================================================
// SDRAM Controller External Bus Interface Unit (0xFFC0 4C00-0xFFC0 4FFF)
====================================================================================*/
#define EBIU_SDGCTL_REG (*(PVUL)(EBIU_SDGCTL)) // SDRAM Global Control Register
#define EBIU_SDBCTL_REG (*(PVUL)(EBIU_SDBCTL)) // SDRAM Bank Control Register
#define EBIU_SDRRC_REG  (*(PVUL)(EBIU_SDRRC))  // SDRAM Refresh Rate Control Register
#define EBIU_SDSTAT_REG (*(PVUL)(EBIU_SDSTAT)) // SDRAM Status Register

/*==================================================================================
// Event/Interrupt Registers
====================================================================================*/
#define EVT0_REG		  (*(PVUL)(EVT0))  // Event Vector 0 ESR Address
#define EVT1_REG          (*(PVUL)(EVT1))  // Event Vector 1 ESR Address
#define EVT2_REG          (*(PVUL)(EVT2))  // Event Vector 2 ESR Address
#define EVT3_REG          (*(PVUL)(EVT3))  // Event Vector 3 ESR Address
#define EVT4_REG          (*(PVUL)(EVT4))  // Event Vector 4 ESR Address
#define EVT5_REG          (*(PVUL)(EVT5))  // Event Vector 5 ESR Address
#define EVT6_REG          (*(PVUL)(EVT6))  // Event Vector 6 ESR Address
#define EVT7_REG          (*(PVUL)(EVT7))  // Event Vector 7 ESR Address
#define EVT8_REG          (*(PVUL)(EVT8))  // Event Vector 8 ESR Address
#define EVT9_REG          (*(PVUL)(EVT9))  // Event Vector 9 ESR Address
#define EVT10_REG         (*(PVUL)(EVT10)) // Event Vector 10 ESR Address
#define EVT11_REG         (*(PVUL)(EVT11)) // Event Vector 11 ESR Address
#define EVT12_REG         (*(PVUL)(EVT12)) // Event Vector 12 ESR Address
#define EVT13_REG         (*(PVUL)(EVT13)) // Event Vector 13 ESR Address
#define EVT14_REG         (*(PVUL)(EVT14)) // Event Vector 14 ESR Address
#define EVT15_REG         (*(PVUL)(EVT15)) // Event Vector 15 ESR Address
#define EVT_OVERRIDE_REG  (*(PVUL)(EVT_OVERRIDE))// Event Vector Table Override Register
#define IMASK_REG         (*(PVUL)(IMASK)) // Interrupt Mask Register
#define IPEND_REG         (*(PVUL)(IPEND)) // Interrupt Pending Register
#define ILAT_REG          (*(PVUL)(ILAT))  // Interrupt Latch Register

/*==================================================================================
// Core Timer Registers
====================================================================================*/
#define TCNTL_REG    (*(PVUL)(TCNTL))    // Core Timer Control Register
#define TPERIOD_REG  (*(PVUL)(TPERIOD))  // Core Timer Period Register
#define TSCALE_REG   (*(PVUL)(TSCALE))   // Core Timer Scale Register
#define TCOUNT_REG   (*(PVUL)(TCOUNT))   // Core Timer Count Register

/*==================================================================================
// Debug/MP/Emulation Registers
====================================================================================*/
#define DSPID_REG    (*(PVUL)(DSPID))    // DSP Processor ID Register for MP implementations
#define DBGCTL_REG   (*(PVUL)(DBGCTL))   // Debug Control Register
#define DBGSTAT_REG  (*(PVUL)(DBGSTAT))  // Debug Status Register
#define EMUDAT_REG   (*(PVUL)(EMUDAT))   // Emulator Data Register

/*==================================================================================
// Trace Buffer Registers
====================================================================================*/
#define TBUFCTL_REG   (*(PVUL)(TBUFCTL))   // Trace Buffer Control Register
#define TBUFSTAT_REG  (*(PVUL)(TBUFSTAT))  // Trace Buffer Status Register
#define TBUF_REG      (*(PVUL)(TBUF))      // Trace Buffer

/*==================================================================================
// Watch Point Control Registers
====================================================================================*/
#define WPIACTL_REG    (*(PVUL)(WPIACTL))  // Instruction Watch Point Control Register
#define WPIA0_REG      (*(PVUL)(WPIA0))    // Instruction Watch Point Address 0
#define WPIA1_REG      (*(PVUL)(WPIA1))    // Instruction Watch Point Address 1
#define WPIA2_REG      (*(PVUL)(WPIA2))    // Instruction Watch Point Address 2
#define WPIA3_REG      (*(PVUL)(WPIA3))    // Instruction Watch Point Address 3
#define WPIA4_REG      (*(PVUL)(WPIA4))    // Instruction Watch Point Address 4
#define WPIA5_REG      (*(PVUL)(WPIA5))    // Instruction Watch Point Address 5
#define WPIACNT0_REG   (*(PVUL)(WPIACNT0)) // Instruction Watch Point Counter 0
#define WPIACNT1_REG   (*(PVUL)(WPIACNT1)) // Instruction Watch Point Counter 1
#define WPIACNT2_REG   (*(PVUL)(WPIACNT2)) // Instruction Watch Point Counter 2
#define WPIACNT3_REG   (*(PVUL)(WPIACNT3)) // Instruction Watch Point Counter 3
#define WPIACNT4_REG   (*(PVUL)(WPIACNT4)) // Instruction Watch Point Counter 4
#define WPIACNT5_REG   (*(PVUL)(WPIACNT5)) // Instruction Watch Point Counter 5
#define WPDACTL_REG    (*(PVUL)(WPDACTL))  // Data Watch Point Control Register
#define WPDA0_REG      (*(PVUL)(WPDA0))    // Data Watch Point Address 0
#define WPDA1_REG      (*(PVUL)(WPDA1))    // Data Watch Point Address 1
#define WPDACNT0_REG   (*(PVUL)(WPDACNT0)) // Data Watch Point Counter 0
#define WPDACNT1_REG   (*(PVUL)(WPDACNT1)) // Data Watch Point Counter 1
#define WPSTAT_REG     (*(PVUL)(WPSTAT))   // Watch Point Status Register

/*==================================================================================
// Performance Monitor Registers
====================================================================================*/
#define PFCTL_REG     (*(PVUL)(PFCTL))    // Performance Monitor Control Register
#define PFCNTR0_REG   (*(PVUL)(PFCNTR0))  // Performance Monitor Counter Register 0
#define PFCNTR1_REG   (*(PVUL)(PFCNTR1))  // Performance Monitor Counter Register 1




//===============================================================================
/*
// setup the General purpose register first !
#define FIO_DIR_REG		(*(PVUS)(FIO_DIR))
#define FIO_FLAG_S_REG	(*(PVUS)(FIO_FLAG_S))
#define FIO_FLAG_C_REG	(*(PVUS)(FIO_FLAG_C))

// setup the timer register 
#define TPERIOD_REG (*(PVUL)(TPERIOD))
#define TSCALE_REG  (*(PVUL)(TSCALE))
#define TCOUNT_REG  (*(PVUL)(TCOUNT))
#define TCNTL_REG	(*(PVUL)(TCNTL))

// setup interrupt mask register
#define IMASK_REG	(*(PVUL)(IMASK))
#define IPEND_REG	(*(PVUL)(IPEND))
#define ILAT_REG	(*(PVUL)(ILAT))
*/


//------------------------------------------------------------------------------
// Flag pins 
//------------------------------------------------------------------------------

#define bPF0		0
#define bPF1		1
#define bPF2		2
#define bPF3		3
#define bPF4		4
#define bPF5		5
#define bPF6		6
#define bPF7		7
#define bPF8		8
#define bPF9		9
#define bPF10		10
#define bPF11		11
#define bPF12		12
#define bPF13		13
#define bPF14		14


//------------------------------------------------------------------------------
// SPORTx 
//------------------------------------------------------------------------------

// SPORTx_TX_CONFIG 

#define	bTxTSPEN 0
#define	bTxICLK  1
#define	bTxDTYPE 2
#define	bTxSENDN 4
#define	bTxSLEN  5
#define	bTxITFS  9
#define	bTxTFSR  10
#define	bTxDITFS 11
#define	bTxLTFS  12
#define	bTxLATFS 13
#define	bTxCKFE  14
#define	bTxICLKD 15

//..............................................................................

// SPORTx_RX_CONFIG 

#define	bRxRSPEN 0
#define	bRxICLK  1
#define	bRxDTYPE 2
#define	bRxSENDN 4
#define	bRxSLEN  5
#define	bRxIRFS  9
#define	bRxRFSR  10
#define	bRxLRFS  12
#define	bRxLARFS 13
#define	bRxCKFE  14
#define	bRxICLKD 15

//..............................................................................
// SPORTx_STAT
#define bROVF 0
#define bRXS 1
#define bTXS 2
#define bTUVF 3
#define bCHNL 4

//..............................................................................
// SPORTx_IRQSTAT_RX

#define bRxCOMPL  0 
#define bRxERR    1
#define bRxBUSERR 2

// SPORTx_IRQSTAT_TX

#define bTxCOMPL  0 
#define bTxERR    1
#define bTxBUSERR 2
 
// SPORTx_MCMC1

#define bMCM   0
#define bMFD   1
#define bWSIZE 5
#define bWOFF  9

// SPORTx_MCMC2

#define bMCCRM   0
#define bMCDTXPE 2
#define bMCDRXPE 3
#define bMCOM    4
#define bMCFF    5
#define bFSDR    7

// SPORTx_CONFIG_DMA_TX

#define bTxDEN   0
#define bTxTRAN  1
#define bTxDCOME 2
#define bTxDSB0  3
#define bTxDAUTO 4
#define bTxFLSH  7
#define bTxDERE  8
#define bTxTUVF  9
#define bTxDSB1  12
#define bTxFS    12
#define bTxDS    14
#define bTxDOWN  15

#define kTxDAUTO   ZET(bTxDAUTO,1) 

// SPORTx_CONFIG_DMA_RX

#define bRxDEN   0
#define bRxTRAN  1
#define bRxDCOME 2
#define bRxDSB0  3
#define bRxDAUTO 4
#define bRxFLSH  7
#define bRxDERE  8
#define bRxROVF  9
#define bRxDSB1  12
#define bRxFS    12
#define bRxDS    14
#define bRxDOWN  15





#endif
